schema_block_len

Function schema_block_len 

pub fn schema_block_len(stream: &[u8]) -> Option<usize>
Length of the leading schema-message block of a full IPC stream produced by encode_ipc_into (so a receiver can split it into the schema prefix and the record-batch+body), or None if stream is not a framed IPC message.