Module event_stream

Module event_stream 

Asynchronous event stream and daemon communication.

Modules

extensions
Drop notifications for the daemon’s opaque extension table. Drop notifications for the daemon’s opaque extension table.
input_tracker
Tracks input health (timeouts, liveness) for circuit-breaker recovery.
merged
Merged event streams combining internal and external event sources. Merge external stream into an EventStream.

Structs

EventScheduler
This scheduler will make sure that there is fairness between inputs.
EventStream
Asynchronous iterator over the incoming Events destined for this node.

Enums

Event
Represents an incoming Dora event.
StopCause
The reason for closing the event stream.
TryRecvError
No event is available right now or the event stream has been closed.

Functions

data_to_arrow_array
Convert an optional DataMessage into an Arrow array, or return an empty null array when no data is present.