pub fn init_tracing(
node_id: &NodeId,
dataflow_id: &DataflowId,
) -> NodeResult<Arc<Mutex<Option<OtelGuard>>>>Expand description
Init Opentelemetry Tracing
This requires a tokio runtime spawning this function to be functional
pub fn init_tracing(
node_id: &NodeId,
dataflow_id: &DataflowId,
) -> NodeResult<Arc<Mutex<Option<OtelGuard>>>>Init Opentelemetry Tracing
This requires a tokio runtime spawning this function to be functional