Asynchronous event stream and daemon communication.
Modules
- extensions
- Drop notifications for the daemon’s opaque extension table. Drop notifications for the daemon’s opaque extension table.
- input_
tracker - Tracks input health (timeouts, liveness) for circuit-breaker recovery.
- merged
- Merged event streams combining internal and external event sources.
Merge external stream into an
EventStream.
Structs
- Event
Scheduler - This scheduler will make sure that there is fairness between inputs.
- Event
Stream - Asynchronous iterator over the incoming
Events destined for this node.
Enums
- Event
- Represents an incoming Dora event.
- Stop
Cause - The reason for closing the event stream.
- TryRecv
Error - No event is available right now or the event stream has been closed.
Functions
- data_
to_ arrow_ array - Convert an optional
DataMessageinto an Arrow array, or return an empty null array when no data is present.