pub fn into_vec<T>(data: &ArrowData) -> Result<Vec<T>, Report>Expand description
Tries to convert the given Arrow array into a Vec of integers or floats.
Returns an error if the array contains any null values, consistent
with every other TryFrom<&ArrowData> impl in this crate.